==> mame_0.182.orig.tar.xz: mame-0.182/src/devices/bus/electron/plus3.h <==
// license:BSD-3-Clause
// copyright-holders:Nigel Barnes
/**********************************************************************

    ALA13 - Acorn Plus 3

**********************************************************************/


#ifndef __ELECTRON_PLUS3__
#define __ELECTRON_PLUS3__

#include "emu.h"
#include "exp.h"
#include "machine/wd_fdc.h"
#include "formats/acorn_dsk.h"

//**************************************************************************
//  TYPE DEFINITIONS
//**************************************************************************

class electron_plus3_device:
	public device_t,
	public device_electron_expansion_interface
{
public:
	// construction/destruction
	electron_plus3_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);

	DECLARE_FLOPPY_FORMATS(floppy_formats);

	// optional information overrides
	virtual machine_config_constructor device_mconfig_additions() const override;
	virtual const tiny_rom_entry *device_rom_region() const override;

	DECLARE_READ8_MEMBER(wd1770_status_r);
	DECLARE_WRITE8_MEMBER(wd1770_status_w);

protected:
	// device-level overrides
	virtual void device_start() override;
	virtual void device_reset() override;

private:
	required_memory_region m_exp_rom;
	required_device<wd1770_t> m_fdc;
	required_device<floppy_connector> m_floppy0;
	optional_device<floppy_connector> m_floppy1;

	int m_drive_control;
};


// device type definition
extern const device_type ELECTRON_PLUS3;


#endif /* __ELECTRON_PLUS3__ */

==> mame_0.228+dfsg.1.orig.tar.xz: mame-0.228+dfsg.1/src/devices/bus/electron/plus3.h <==
// license:BSD-3-Clause
// copyright-holders:Nigel Barnes
/**********************************************************************

    ALA13 - Acorn Plus 3

**********************************************************************/

#ifndef MAME_BUS_ELECTRON_PLUS3_H
#define MAME_BUS_ELECTRON_PLUS3_H

#include "exp.h"
#include "imagedev/floppy.h"
#include "machine/wd_fdc.h"
#include "formats/acorn_dsk.h"

//**************************************************************************
//  TYPE DEFINITIONS
//**************************************************************************

class electron_plus3_device:
	public device_t,
	public device_electron_expansion_interface
{
public:
	// construction/destruction
	electron_plus3_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);

protected:
	// device-level overrides
	virtual void device_start() override;

	// optional information overrides
	virtual void device_add_mconfig(machine_config &config) override;
	virtual const tiny_rom_entry *device_rom_region() const override;

	virtual uint8_t expbus_r(offs_t offset) override;
	virtual void expbus_w(offs_t offset, uint8_t data) override;

private:
	void wd1770_status_w(uint8_t data);
	DECLARE_FLOPPY_FORMATS(floppy_formats);

	required_device<electron_expansion_slot_device> m_exp;
	required_memory_region m_exp_rom;
	required_device<wd1770_device> m_fdc;
	required_device<floppy_connector> m_floppy0;
	optional_device<floppy_connector> m_floppy1;

	uint8_t m_romsel;
	int m_drive_control;
};


// device type definition
DECLARE_DEVICE_TYPE(ELECTRON_PLUS3, electron_plus3_device)


#endif // MAME_BUS_ELECTRON_PLUS3_H
